@@ -20,7 +20,7 @@ def convert2mnn(model, input_shape, path, verbose=False):
     """Convert pytorch model to mnn format."""
     model.eval().cuda()
     dummy_input = torch.randn(input_shape, device='cuda')
-    if isinstance(model, torch.nn.Embedding):
+    if check_emb(model):
         dummy_input = torch.ones(input_shape, device='cuda').long()
     input_names = ["input"]
     output_names = ["output"]
@@ -96,11 +96,11 @@ def export_models(net, input_shape, fp, verbose=False):
     if not os.path.isdir(fp):
         os.mkdir(fp)
         logger.info("Create %s" % fp)
-    torch_path = os.path.join(fp, net.__repr__()+'.pth')
+    torch_path = os.path.join(fp, net.__repr__() + '.pth')
     torch.save(net, torch_path)
     mnn_name = convert2mnn(net, input_shape, fp, verbose=verbose)
     kwargs = dict()
-    kwargs["torch_name"] = net.__repr__()+'.pth'
+    kwargs["torch_name"] = net.__repr__() + '.pth'
     kwargs["input_shape"] = input_shape
     with open(os.path.join(fp, mnn_name[:-4] + "meta.json"), "w") as f:
         json.dump(kwargs, f)
@@ -128,9 +128,14 @@ def validation(fp, ops_path, verbose=False, save_path=None):
         import pandas as pd
         import numpy as np
         data = np.array(data)
-        pd.DataFrame({"model": data[:, 0], "latency_true(ms)": data[:, 1], "latency_pred(ms)": data[:, 2]}).to_csv(save_path)
-
-
-
+        pd.DataFrame({"model": data[:, 0], "latency_true(ms)": data[:, 1], "latency_pred(ms)": data[:, 2]}).to_csv(
+            save_path)
 
 
+def check_emb(model):
+    is_emb = False
+    for m in model.modules():
+        is_emb = isinstance(m, torch.nn.Embedding)
+        if is_emb:
+            return is_emb
+    return is_emb
