@@ -61,7 +61,7 @@ def predict_latency(module, ops_path, input_shape, verbose=False):
     device = get_net_device(module)
     module.eval()
     x = torch.ones(input_shape).to(device)
-    if isinstance(module, torch.nn.Embedding):
+    if check_emb(module):
         x = x.long()
     _ = module(x)
     result.append(("Sum", "-", "-", latency_all[0]))
@@ -141,7 +141,16 @@ def summary_model(model, input_size, ops_list, verbose=False):
     device = get_net_device(module)
     module.eval()
     x = torch.ones(input_size).to(device)
-    if isinstance(module, torch.nn.Embedding):
+    if check_emb(module):
         x = x.long()
     _ = module(x)
     print(tabulate(ops_input_shape, headers=headers))
+
+
+def check_emb(model):
+    is_emb = False
+    for m in model.modules():
+        is_emb = isinstance(m, torch.nn.Embedding)
+        if is_emb:
+            return is_emb
+    return is_emb
